==> mktcenter-service-1.5.2-vg-20220804.104750-29-sources.jar: com/bizvane/mktcenterservice/models/bo/TaskWXDetailBO.java <==
package com.bizvane.mktcenterservice.models.bo;

import com.fasterxml.jackson.annotation.JsonFormat;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * @Author: lijunwei
 * @Time: 2018/8/15 11:50
 */
public class TaskWXDetailBO {
    private Long mktTaskId;
    private String taskName ;
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            locale = "zh",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd"
    )
    private Date startTime;
  @JsonFormat(
            pattern = "yyyy-MM-dd",
            locale = "zh",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd"
    )
    private Date   endTime;
    private  String  taskInfo;
    private Integer points;
    private String shareTitle;
    private String shareImg;
    private Integer taskType;
    private Long sysCompanyId;
    private Long sysBrandId;

    public String getShareTitle() {
        return shareTitle;
    }

    public void setShareTitle(String shareTitle) {
        this.shareTitle = shareTitle;
    }

    public String getShareImg() {
        return shareImg;
    }

    public void setShareImg(String shareImg) {
        this.shareImg = shareImg;
    }

    List<TaskCouponWXBO>  taskCouponWXBOs;

    public Long getMktTaskId() {
        return mktTaskId;
    }

    public void setMktTaskId(Long mktTaskId) {
        this.mktTaskId = mktTaskId;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getTaskInfo() {
        return taskInfo;
    }

    public void setTaskInfo(String taskInfo) {
        this.taskInfo = taskInfo;
    }

    public Integer getPoints() {
        return points;
    }

    public void setPoints(Integer points) {
        this.points = points;
    }

    public List<TaskCouponWXBO> getTaskCouponWXBOs() {
        return taskCouponWXBOs;
    }

    public void setTaskCouponWXBOs(List<TaskCouponWXBO> taskCouponWXBOs) {
        this.taskCouponWXBOs = taskCouponWXBOs;
    }

    public Integer getTaskType() {
        return taskType;
    }

    public void setTaskType(Integer taskType) {
        this.taskType = taskType;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }
}

==> mktcenter-service-1.5.3-vg-20221108.085411-15-sources.jar: com/bizvane/mktcenterservice/models/bo/TaskWXDetailBO.java <==
package com.bizvane.mktcenterservice.models.bo;

import com.fasterxml.jackson.annotation.JsonFormat;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * @Author: lijunwei
 * @Time: 2018/8/15 11:50
 */
public class TaskWXDetailBO {
    private Long mktTaskId;
    private String taskName ;
    private String memberTouristName;
    private String memberTouristUrl;

    public String getMemberTouristName() {
        return memberTouristName;
    }

    public void setMemberTouristName(String memberTouristName) {
        this.memberTouristName = memberTouristName;
    }

    public String getMemberTouristUrl() {
        return memberTouristUrl;
    }

    public void setMemberTouristUrl(String memberTouristUrl) {
        this.memberTouristUrl = memberTouristUrl;
    }

    @JsonFormat(
            pattern = "yyyy-MM-dd",
            locale = "zh",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd"
    )
    private Date startTime;
  @JsonFormat(
            pattern = "yyyy-MM-dd",
            locale = "zh",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd"
    )
    private Date   endTime;
    private  String  taskInfo;
    private Integer points;
    private String shareTitle;
    private String shareImg;
    private Integer taskType;
    private Long sysCompanyId;
    private Long sysBrandId;

    public String getShareTitle() {
        return shareTitle;
    }

    public void setShareTitle(String shareTitle) {
        this.shareTitle = shareTitle;
    }

    public String getShareImg() {
        return shareImg;
    }

    public void setShareImg(String shareImg) {
        this.shareImg = shareImg;
    }

    List<TaskCouponWXBO>  taskCouponWXBOs;

    public Long getMktTaskId() {
        return mktTaskId;
    }

    public void setMktTaskId(Long mktTaskId) {
        this.mktTaskId = mktTaskId;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getTaskInfo() {
        return taskInfo;
    }

    public void setTaskInfo(String taskInfo) {
        this.taskInfo = taskInfo;
    }

    public Integer getPoints() {
        return points;
    }

    public void setPoints(Integer points) {
        this.points = points;
    }

    public List<TaskCouponWXBO> getTaskCouponWXBOs() {
        return taskCouponWXBOs;
    }

    public void setTaskCouponWXBOs(List<TaskCouponWXBO> taskCouponWXBOs) {
        this.taskCouponWXBOs = taskCouponWXBOs;
    }

    public Integer getTaskType() {
        return taskType;
    }

    public void setTaskType(Integer taskType) {
        this.taskType = taskType;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }
}
